Crate tokio_childstream

Crate tokio_childstream 

Convert a tokio::process::Child into a futures::Stream which yields ChildEvents for stdout, stderr, and the exit status.

Structs

ChildStream
Provide a Stream over StreamItems from a tokio::process::Child

Enums

ChildEvent
Represents events from a ChildStream
OutputSource
Indicate the source of ChildEvent::Output

Traits

CommandExt
Extend tokio::process::Command to enable spawning a child directly into a ChildStream

Type Aliases

StreamItem
The ChildStream items yield a Result of either a ChildEvent or std::io::Error