CommandExt

Trait CommandExt 

pub trait CommandExt {
    // Required method
    fn spawn_stream(&mut self, line_buffering: bool) -> Result<ChildStream>;
}
Extend tokio::process::Command to enable spawning a child directly into a ChildStream

Required Methods

fn spawn_stream(&mut self, line_buffering: bool) -> Result<ChildStream>

Spawn a child process and convert it into a ChildStream with line_buffering optionally enabled

See ChildStream for a description of line-buffering.

Implementations on Foreign Types

Source

impl CommandExt for Command

Source

fn spawn_stream(&mut self, line_buffering: bool) -> Result<ChildStream>

Implementors