Convert a tokio::process::Child into a futures::Stream which yields ChildEvents for stdout, stderr, and the exit status.
Structs
- Child
Stream - Provide a Stream over StreamItems from a tokio::process::Child
Enums
- Child
Event - Represents events from a ChildStream
- Output
Source - Indicate the source of ChildEvent::Output
Traits
- Command
Ext - Extend tokio::process::Command to enable spawning a child directly into a ChildStream
Type Aliases
- Stream
Item - The ChildStream items yield a Result of either a ChildEvent or std::io::Error