pub trait CommandExt {
// Required method
fn spawn_stream(&mut self, line_buffering: bool) -> Result<ChildStream>;
}Expand description
Extend tokio::process::Command to enable spawning a child directly into a ChildStream
Required Methods
Sourcefn spawn_stream(&mut self, line_buffering: bool) -> Result<ChildStream>
fn spawn_stream(&mut self, line_buffering: bool) -> Result<ChildStream>
Spawn a child process and convert it into a ChildStream with line_buffering optionally enabled
See ChildStream for a description of line-buffering.